Module event

Available on crate feature event only.
event traits and overall logic for event emitting and listening

Modules

state_helperNon-target_family="wasm" and initial_value
A mod containing functions to acquire a wrapped state manged by tauri

Structs

ListenHandletarget_family="wasm"
Handle which holds the function to detach the listener and the correlated callback
Payloadtarget_family="wasm"
The generic payload received from listen used for deserialization

Enums

EventErrorinitial_value
General errors that can happen during event exchange
ListenErrortarget_family="wasm"
Errors that can occur during registering the callback in ListenHandle::register

Traits

EmitNon-target_family="wasm"
Trait that defines the available event emitting methods
Field
Trait defining a Field to a related struct implementing Parent with the related Field::Type
Listentarget_family="wasm"
Trait that defines the available listen methods
ManagedEmitNon-target_family="wasm" and initial_value
Extension of Emit to additionally require Self to be managed by tauri

Type Aliases

ListenResulttarget_family="wasm"
The result type that is returned by ListenHandle::register

Trait Aliases

ParentNon-target_family="wasm"
The trait which needs to be implemented for a Field