Struct ListenHandle

pub struct ListenHandle {
    pub closure: Option<Closure<dyn Fn(JsValue)>>,
    /* private fields */
}
Available on target_family="wasm" and crate feature event only.
Handle which holds the function to detach the listener and the correlated callback

Fields

closure: Option<Closure<dyn Fn(JsValue)>>

The callback which is invoked for the registered event

The callback will get detached, when the handle is dropped. Alternatively it can also be given to the js runtime (see Closure into_js_value/forget). This isn’t recommended because this will leak memory by default.

Implementations

Source

impl ListenHandle

pub async fn register<T>( event: &'static str, callback: impl Fn(T) + 'static, ) -> ListenResult

Registers a given event with the correlation callback and returns a ListenResult

pub fn detach_listen(&mut self)

Detaches the callback from the registered event

pub fn use_register<P, F: Field<P>>( initial_value: Option<F::Type>, ) -> ReadSignal<<F as Field<P>>::Type, LocalStorage>
where P: Parent,

Available on crate feature leptos only.

Registers a given event and binds a returned signal to these event changes

Providing None will unwrap into the default value. When feature initial_value is enabled None will try to get the value from tauri.

Internally it stores a created ListenHandle for event in a leptos::prelude::RwSignal to hold it in scope, while it is used in a leptos component