Available on crate feature
event only.Expand description
event traits and overall logic for event emitting and listening
Modules
- state_
helper Non- target_family="wasm"andinitial_value - A mod containing functions to acquire a wrapped state manged by tauri
Structs
- Listen
Handle target_family="wasm" - Handle which holds the function to detach the listener and the correlated callback
- Payload
target_family="wasm" - The generic payload received from listen used for deserialization
Enums
- Event
Error initial_value - General errors that can happen during event exchange
- Listen
Error target_family="wasm" - Errors that can occur during registering the callback in ListenHandle::register
Traits
- Emit
Non- target_family="wasm" - Trait that defines the available event emitting methods
- Field
- Trait defining a Field to a related struct implementing Parent with the related Field::Type
- Listen
target_family="wasm" - Trait that defines the available listen methods
- Managed
Emit Non- target_family="wasm"andinitial_value - Extension of Emit to additionally require Self to be managed by tauri
Type Aliases
- Listen
Result target_family="wasm" - The result type that is returned by ListenHandle::register